@@ -1,13 +1,10 @@
 # import packages/modules
 import pandas as pd
 import math
-import sympy as sp
-import yaml
 import json
-from typing import Literal
+from typing import Literal, Optional, List, Dict, Any
 # local
 from ..models import EquationResult
-from .equationbuilder import EquationBuilder
 from ..utils import format_eq_data
 
 
@@ -31,12 +28,39 @@ class TableEquation:
     # selected equation id
     eq_id: int = -1
 
-    def __init__(self, databook_name, table_name, equations):
+    def __init__(
+        self,
+        databook_name,
+        table_name,
+        equations,
+        table_values: Optional[List | Dict] = None,
+        table_structure: Optional[Dict[str, Any]] = None
+    ):
+        '''
+        Initialize the TableEquation class.
+
+        Parameters
+        ----------
+        databook_name : str
+            Name of the databook.
+        table_name : str
+            Name of the table.
+        equations : list
+            List of equations.
+        table_values : list, optional
+            Values for the table (default is None), if provided in yml file.
+        table_structure : dict, optional
+            Structure of the table (default is None), if provided in yml file.
+        '''
         self.databook_name = databook_name
         self.table_name = table_name
-        self.equations = equations
+        self.equations = equations  # equation list structures (yml file)
         # number of equations
         self.eq_num = len(equations)
+        # table values (yml)
+        self.__table_values = table_values if table_values else None
+        # table structure (yml)
+        self.__table_structure = table_structure if table_structure else None
 
     @property
     def trans_data(self):
@@ -77,6 +101,32 @@ class TableEquation:
             'custom_integral': self._custom_integral
         }
 
+    @property
+    def table_values(self):
+        '''Get table values from yml file (if exists)'''
+        if self.__table_values:
+            return self.__table_values
+        else:
+            msg = f"""No table values found in the following reference \n
+            ::: {self.databook_name}
+            :::  {self.table_name}!
+            """
+            print(msg)
+            return None
+
+    @property
+    def table_structure(self):
+        '''Get table structure from yml file (if exists)'''
+        if self.__table_structure:
+            return self.__table_structure
+        else:
+            msg = f"""No table structure found in the following reference \n
+            ::: {self.databook_name}
+            :::  {self.table_name}!
+            """
+            print(msg)
+            return None
+
     def eq_structure(self, id=1):
         '''
         Display equation details
@@ -192,6 +242,111 @@ class TableEquation:
         except Exception as e:
             raise Exception(f'Loading error {e}!')
 
+    @property
+    def table_columns(self, column_name: str = 'COLUMNS'):
+        '''
+        Display table columns defined in `yml file`
+
+        Parameters
+        ----------
+        column_name : str, optional
+            column name (default is 'COLUMNS')
+
+        Returns
+        -------
+        columns : list
+            table columns
+        '''
+        try:
+            # table structure
+            table_structure = self.table_structure
+
+            # check table structure
+            if table_structure is None:
+                raise Exception('Table structure not defined!')
+
+            # res
+            columns = table_structure.get(column_name, None)
+            # check columns
+            if columns is None:
+                raise Exception(f'Column {column_name} not found!')
+
+            # res
+            return columns
+
+        except Exception as e:
+            raise Exception(f'Loading error {e}!')
+
+    @property
+    def table_units(self, unit_name: str = 'UNIT'):
+        '''
+        Display table units defined in `yml file`
+
+        Parameters
+        ----------
+        unit_name : str, optional
+            unit name (default is 'UNIT')
+
+        Returns
+        -------
+        units : list
+            table units
+        '''
+        try:
+            # table structure
+            table_structure = self.table_structure
+
+            # check table structure
+            if table_structure is None:
+                raise Exception('Table structure not defined!')
+
+            # res
+            units = table_structure.get(unit_name, None)
+            # check units
+            if units is None:
+                raise Exception(f'Unit {unit_name} not found!')
+
+            # res
+            return units
+
+        except Exception as e:
+            raise Exception(f'Loading error {e}!')
+
+    @property
+    def table_symbols(self, symbol_name: str = 'SYMBOL'):
+        '''
+        Display table symbols defined in `yml file`
+
+        Parameters
+        ----------
+        symbol_name : str, optional
+            symbol name (default is 'SYMBOL')
+
+        Returns
+        -------
+        symbols : list
+            table symbols
+        '''
+        try:
+            # table structure
+            table_structure = self.table_structure
+
+            # check table structure
+            if table_structure is None:
+                raise Exception('Table structure not defined!')
+
+            # res
+            symbols = table_structure.get(symbol_name, None)
+            # check symbols
+            if symbols is None:
+                raise Exception(f'Symbol {symbol_name} not found!')
+
+            # res
+            return symbols
+
+        except Exception as e:
+            raise Exception(f'Loading error {e}!')
+
     def eq_info(self):
         '''Get equation information.'''
         try:
@@ -206,7 +361,12 @@ class TableEquation:
         except Exception as e:
             raise Exception(f'Loading error {e}!')
 
-    def cal(self, message: str = '', decimal_accuracy: int = 4, sympy_format: bool = False, **args) -> EquationResult:
+    def cal(
+        self,
+        message: str = '',
+        decimal_accuracy: int = 4,
+        **args
+    ) -> EquationResult:
         '''
         Execute a function
 
@@ -216,8 +376,6 @@ class TableEquation:
             message to be printed
         decimal_accuracy : int
             decimal accuracy (default is 4)
-        sympy_format : bool
-            @deprecated() whether to return sympy format (default is False)
         args : dict
             a dictionary contains variable names and values as
 
@@ -242,15 +400,17 @@ class TableEquation:
         eq_info.update(eq_src)
 
         # build parms dict
-        _parms = self.load_parms()
+        _parms = self.load_parms_v2()
         # execute equation
         # res
         res = None
-        # check
-        if sympy_format:
-            res = self.eqExe_sympy(self.body, _parms, args=args)
-        else:
-            res = self.eqExe(self.body, _parms, args=args)
+
+        # NOTE: execute equation
+        # check body
+        if self.body is None or self.body == 'None':
+            raise Exception('Equation body not defined!')
+
+        res = self.eqExe(self.body, _parms, args=args)
 
         if res is not None:
             res = round(res, decimal_accuracy)
@@ -284,7 +444,7 @@ class TableEquation:
         >>> print(res)
         '''
         # build parms dict
-        _parms = self.load_parms()
+        _parms = self.load_parms_v2()
         # execute equation
         res = self.eqExe(self.body_integral, _parms, args=args)
         return res
@@ -320,7 +480,7 @@ class TableEquation:
                 raise Exception('Equation name not found!')
 
             # build parms dict
-            _parms = self.load_parms()
+            _parms = self.load_parms_v2()
 
             # check
             if len(self._custom_integral) > 0:
@@ -357,11 +517,12 @@ class TableEquation:
         '''
         try:
             # check
-            if self.body_first_derivative is None or self.body_first_derivative == 'None':
+            if (self.body_first_derivative is None or
+                    self.body_first_derivative == 'None'):
                 print('The first derivative not defined!')
 
             # build parms dict
-            _parms = self.load_parms()
+            _parms = self.load_parms_v2()
             # execute equation
             res = self.eqExe(self.body_first_derivative, _parms, args=args)
             return res
@@ -389,11 +550,12 @@ class TableEquation:
         '''
         try:
             # check
-            if self.body_second_derivative is None or self.body_second_derivative == 'None':
+            if (self.body_second_derivative is None or
+                    self.body_second_derivative == 'None'):
                 print('The second derivative not defined!')
 
             # build parms dict
-            _parms = self.load_parms()
+            _parms = self.load_parms_v2()
             # execute equation
             res = self.eqExe(self.body_second_derivative, _parms, args=args)
             return res
@@ -411,16 +573,60 @@ class TableEquation:
             # looping through self.parms
             # check parms
             if isinstance(self.parms, dict):
-                # loaded parms (taken from reference)
+                # NOTE: loaded parms (taken from reference)
                 _parms_name = list(self.parms.keys())
-                _parms = {value['symbol']: float(value['value'] or 0)/float(value['unit'] or 1)
-                          for key, value in trans_data.items() if value['symbol'] in _parms_name}
+                # from symbol
+                _parms_name = [
+                    value['symbol']
+                    for key, value in self.parms.items()
+                ]
+
+                # NOTE: create params dict
+                _parms = {
+                    value['symbol']:
+                    float(value['value'] or 0)/float(value['unit'] or 1)
+                    for key, value in trans_data.items() if value['symbol'] in _parms_name
+                }
             else:
                 _parms = {}
             return _parms
         except Exception as e:
             raise Exception("Loading equation parameters failed!, ", e)
 
+    def load_parms_v2(self):
+        """
+        Load parameter values and store in a dict.
+        These parameters are constant values defined in an equation.
+        """
+        try:
+            trans_data = self.trans_data
+
+            if isinstance(self.parms, dict):
+                # Get the list of symbols we need
+                parm_symbols = [v["symbol"] for v in self.parms.values()]
+
+                def safe_float(x, default=1.0):
+                    """Return float(x) if numeric, else default."""
+                    try:
+                        return float(x)
+                    except (ValueError, TypeError):
+                        return default
+
+                # Build params dict
+                parms = {
+                    v["symbol"]: float(v.get("value", 0)) /
+                    safe_float(v.get("unit"), 1.0)
+                    for v in trans_data.values()
+                    if v["symbol"] in parm_symbols
+                }
+            else:
+                parms = {}
+
+            return parms
+
+        except Exception as e:
+            raise Exception("Loading equation parameters failed!") from e
+
     def equation_body(self):
         '''
         Display equation body
@@ -525,7 +731,7 @@ class TableEquation:
         # load equation
         eq_summary = self.eq_structure(Eq_data)
 
-        # extract data
+        # REVIEW: extract data
         _body = eq_summary['body']
         self.body = ';'.join(_body)
         # check
@@ -593,7 +799,7 @@ class TableEquation:
 
         # check params
         if len(self.parms) > 0:
-            self.__parms_values = self.load_parms()
+            self.__parms_values = self.load_parms_v2()
 
     def eqExe(self, body, parms, args):
         '''
@@ -627,54 +833,6 @@ class TableEquation:
         # Return the result
         return namespace['res']
 
-    def eqExe_sympy(self, body, parms, args):
-        '''
-        Execute the function having args, parameters and body
-
-        Parameters
-        ----------
-        body : str
-            function body
-        parms : dict
-            parameters
-        args : dict
-            args
-
-        Returns
-        -------
-        res : float
-            calculation result
-        '''
-        # str input
-        str_input = []
-        # std body
-        body = body.replace("res =", "")
-        body = body.replace("res=", "")
-        body = body.strip()
-        # check
-        if self.args is not None:
-            # check list
-            for key, value in self.args.items():
-                if 'symbol' in value:
-                    symbol = value['symbol']
-                    str_input.append(symbol)
-        # check
-        if self.parms is not None:
-            for key, value in self.parms.items():
-                if 'symbol' in value:
-                    symbol = value['symbol']
-                    str_input.append(symbol)
-
-        # convert to string
-        str_input = ' '.join(str_input)
-        # init EquationBuilder
-        eq_builder = EquationBuilder(str_input)
-        # all parameters and variables
-        all_parms = {**parms, **args}
-        # execute equation
-        res = eq_builder.evaluate_expression(body, **all_parms)
-        return res
-
     def to_dict(self):
         '''
         Convert equation to dict
